==> orchestra-api-4.0.10-sources.jar: org/ow2/orchestra/facade/uuid/ActivityDefinitionUUID.java <==
/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.facade.uuid;

import org.ow2.orchestra.facade.runtime.ActivityType;

/**
 *
 * @author Gael Lalire
 */
public class ActivityDefinitionUUID extends AbstractUUID {

  private static final long serialVersionUID = -8530809113980131812L;

  private static String getName(final String activityName) {
    if (activityName == null) {
      return "";
    } else {
      return "(" + activityName + ")";
    }
  }

  protected ActivityDefinitionUUID() {
    super();
  }

  public ActivityDefinitionUUID(final ActivityDefinitionUUID src) {
    super(src);
  }

  public ActivityDefinitionUUID(final ProcessDefinitionUUID processUUID, final int activityCount, final ActivityType activityType,
    final String activityName) {
    super(processUUID.value + NUMBER_SEPARATOR + activityCount + SEPARATOR + activityType + getName(activityName));
  }

  ActivityDefinitionUUID(final String value) {
    //this method is necessary to allow admin consoles to create a UUID from a string value
    super(value);
  }
}

==> orchestra-api-4.2.0-sources.jar: org/ow2/orchestra/facade/uuid/ActivityDefinitionUUID.java <==
/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.facade.uuid;

import org.ow2.orchestra.facade.runtime.ActivityType;

/**
 *
 * @author Gael Lalire
 */
public class ActivityDefinitionUUID extends AbstractUUID {

  private static final long serialVersionUID = -8530809113980131812L;

  private static String getName(final String activityName) {
    if (activityName == null) {
      return "";
    } else {
      return "(" + activityName + ")";
    }
  }

  protected ActivityDefinitionUUID() {
    super();
  }

  public ActivityDefinitionUUID(final ActivityDefinitionUUID src) {
    super(src);
  }

  public ActivityDefinitionUUID(final ProcessDefinitionUUID processUUID, final int activityCount, final ActivityType activityType,
    final String activityName) {
    super(processUUID.value + AbstractUUID.NUMBER_SEPARATOR + activityCount + AbstractUUID.SEPARATOR + activityType + ActivityDefinitionUUID.getName(activityName));
  }

  public ActivityDefinitionUUID(final String value) {
    //this method is necessary to allow admin consoles to create a UUID from a string value
    super(value);
  }
}
